> ![MikroE](http://www.mikroe.com/img/designs/beta/logo_small.png)
> #9DOF click#
> ##By [MikroElektronika](http://www.mikroe.com)
---

## Installation
Use the package manager to install the library for your architecture.

###Example
```
#include "dof9_hw.h"
#include "resources.h"

/*******************************************************************************
* TFT init
*******************************************************************************/
// TFT module connections
unsigned int TFT_DataPort at GPIOE_ODR;
sbit TFT_RST at GPIOE_ODR.B8;
sbit TFT_RS at GPIOE_ODR.B12;
sbit TFT_CS at GPIOE_ODR.B15;
sbit TFT_RD at GPIOE_ODR.B10;
sbit TFT_WR at GPIOE_ODR.B11;
sbit TFT_BLED at GPIOE_ODR.B9;
// End TFT module connections

sbit LSM9DS1_EN at GPIOC_ODR.B2;
char tmp;
char text[16];
char xgID, magID;
extern sensor_t LSM9DS1;
char tempUpdateCnt;

static void Display_Init()
{
    TFT_Init_ILI9341_8bit( 320, 240 );
    TFT_Set_Pen( CL_WHITE, 1 );
    TFT_Set_Brush( 1, CL_WHITE, 0, 0, 0, 0 );
    TFT_Set_Font( TFT_defaultFont, CL_BLACK, FO_HORIZONTAL );
    TFT_Fill_Screen( CL_WHITE );
    TFT_Set_Pen( CL_Black, 1 );
    TFT_Line( 20, 220, 300, 220 );
    TFT_LIne( 20,  40, 300,  40 );
    TFT_Set_Font( &HandelGothic_BT21x22_Regular, CL_RED, FO_HORIZONTAL );
    TFT_Write_Text( "9DOF click", 100, 10 );
    TFT_Set_Font( &Verdana12x13_Regular, CL_BLACK, FO_HORIZONTAL );
    TFT_Write_Text( "EasyMx PRO v7 for STM32", 19, 223 );
    TFT_Set_Font( &Verdana12x13_Regular, CL_RED, FO_HORIZONTAL );
    TFT_Write_Text( "www.mikroe.com", 200, 223 );
    TFT_Set_Font( &TFT_defaultFont, CL_BLACK, FO_HORIZONTAL );
}

static void Values_Init()
{
    TFT_Write_Text( "Accel X:", 20, 55 );
    TFT_Write_Text( "Accel Y:", 20, 70 );
    TFT_Write_Text( "Accel Z:", 20, 85 );
    TFT_Write_Text( "Mag X:", 170, 55 );
    TFT_Write_Text( "Mag Y:", 170, 70 );
    TFT_Write_Text( "Mag Z:", 170, 85 );
    TFT_Write_Text( "Gyro X:", 20, 115 );
    TFT_Write_Text( "Gyro Y:", 20, 130 );
    TFT_Write_Text( "Gyro Z:", 20, 145 );
    TFT_Write_Text( "Temperature:", 20, 175 );
}

static void Clear_Area_Accel( unsigned int startX, unsigned int startY )
{
    TFT_Set_Pen( CL_WHITE, 1 );
    TFT_Rectangle( startX, startY, 155, startY + 15 );
}

static void Clear_Area( unsigned int startX, unsigned int startY )
{
    TFT_Set_Pen( CL_WHITE, 1 );
    TFT_Rectangle( startX, startY, 310, startY + 15 );
}

//------------------------------------------------------------------------------
// Accel Values
//------------------------------------------------------------------------------
static void Display_AccelValues()    //[mg]
{
    IntToStr( ( int )( 1000 * LSM9DS1.accelX ), text );
    Clear_Area_Accel( 80, 55 );
    TFT_Write_Text( text, 80, 55 );
    IntToStr( ( int )( 1000 * LSM9DS1.accelY ), text );
    Clear_Area_Accel( 80, 70 );
    TFT_Write_Text( text, 80, 70 );
    IntToStr( ( int )( 1000 * LSM9DS1.accelZ ), text );
    Clear_Area_Accel( 80, 85 );
    TFT_Write_Text( text, 80, 85 );
}

//------------------------------------------------------------------------------
// Mag Values
//------------------------------------------------------------------------------
static void Display_MagValues()    //[mG]
{
    IntToStr( ( int )( 1000 * LSM9DS1.magX ), text );
    Clear_Area( 220, 55 );
    TFT_Write_Text( text, 220, 55 );
    IntToStr( ( int )( 1000 * LSM9DS1.magY ), text );
    Clear_Area( 220, 70 );
    TFT_Write_Text( text, 220, 70 );
    IntToStr( ( int )( 1000 * LSM9DS1.magZ ), text );
    Clear_Area( 220, 85 );
    TFT_Write_Text( text, 220, 85 );
}

//------------------------------------------------------------------------------
// Gyro Values
//------------------------------------------------------------------------------
static void Display_GyroValues()    //[deg/sec]
{
    FloatToStr( LSM9DS1.gyroX, text );
    Clear_Area( 80, 115 );
    TFT_Set_Pen( CL_Black, 1 );
    TFT_Write_Text( text, 80, 115 );
    FloatToStr( LSM9DS1.gyroY, text );
    Clear_Area( 80, 130 );
    TFT_Write_Text( text, 80, 130 );
    FloatToStr( LSM9DS1.gyroZ, text );
    Clear_Area( 80, 145 );
    TFT_Write_Text( text, 80, 145 );
}

//------------------------------------------------------------------------------
// Temperature Value
//------------------------------------------------------------------------------
static void Display_Temperature()    //[degrees C]
{
    FloatToStr( LSM9DS1.temperature, text );
    Clear_Area( 120, 175 );
    TFT_Write_Text( text, 120, 175 );
    tempUpdateCnt = 0;
}

//------------------------------------------------------------------------------
// Calibration
//------------------------------------------------------------------------------
void calibration( void )
{
    xgID = LSM9DS1_GetGyroID();
    magID = LSM9DS1_GetMagID();
    if ( ( xgID == XG_ID ) && ( magID == MAG_ID ) )
        TFT_Write_Text( "Calibrating, please wait...", 80, 95 );
    else
    {
        TFT_Write_Text( "Error", 80, 95 );
        while( 1 ); //stop program
    }
    LSM9DS1_CalibrateXG();
    LSM9DS1_CalibrateMag();
    TFT_Write_Text( "Calibrating done.", 100, 110 );
    delay_ms( 500 );
    Clear_Area( 80, 95 );
    Clear_Area( 90, 110 );
    LSM9DS1_Init();
    delay_ms( 1000 );
    Values_Init();
    delay_ms( 100 );
}

/*******************************************************************************
* System init
*******************************************************************************/
static void System_Init()
{
    GPIO_Digital_Input( &GPIOD_BASE, _GPIO_PINMASK_10 );
    GPIO_Digital_Output( &GPIOC_BASE, _GPIO_PINMASK_2 );
    I2C1_Init_Advanced( 400000, &_GPIO_MODULE_I2C1_PB67 );
    delay_ms( 200 );
    LSM9DS1_i2c_init( LSM9DS1M_ADDRESS, LSM9DS1XG_ADDRESS );
    delay_ms( 200 );
}
```

```
void main()
{
    System_Init();
    LSM9DS1_EN = 1;
    delay_ms( 10 );
    Display_Init();
    //Check if LSM9DS1 chip present
    calibration();
    LSM9DS1_ReadTemperatureData();
    Display_Temperature();
    while( 1 )
    {
        if( LSM9DS1_AccelDataReady() )
        {
            LSM9DS1_ReadAccelData();
            Display_AccelValues();
        }
        if( LSM9DS1_GyroDataReady() )
        {
            LSM9DS1_ReadGyroData();
            Display_GyroValues();
        }
        if( LSM9DS1_MagDataReady() )
        {
            LSM9DS1_ReadMagData();
            Display_MagValues();
        }
        //~1sec we update temperature value on display
        if ( tempUpdateCnt == 9 )
        {
            LSM9DS1_ReadTemperatureData();
            Display_Temperature();
        }
        else
            tempUpdateCnt++;
        delay_ms( 100 );
    }
}
```